import { getProjectMap } from '../api'

interface State {
  id: string
  name: string
}
interface Project {
  project_id: string
  roles: string[]
  permissions: string[]
  tags: Record<string, string>
}

const types = ref<State[]>([])
const status = ref<State[]>([])
const authProjectList = ref<Project[]>([])
const tags = ref<Record<string, string>>({})

export function useMap() {
  const projectId = ref('')
  const prefix = ref('')
  function fetchInfo() {
    getProjectMap().then((res: any) => {
      const data = res.data
      types.value =
        data.project_type_map?.map((item: { id: number; name: string }) => ({ ...item, id: item.id.toString() })) || []
      status.value =
        data.project_status_map?.map((item: { id: number; name: string }) => ({ ...item, id: item.id.toString() })) ||
        []
      authProjectList.value = data.project_auth_map || []
      tags.value = data.tags || {}
    })
  }
  if (!authProjectList.value.length) fetchInfo()

  // 当前项目
  const project = computed(() => {
    return authProjectList.value.find(item => item.project_id === projectId.value)
  })

  // 是否需要权限控制
  function isAuth(key: string, pre: string = prefix.value) {
    const prop = pre + key
    return Object.prototype.hasOwnProperty.call(tags.value, prop)
  }
  // 有没有权限
  function hasAuth(key: string, pid: string = projectId.value, pre: string = prefix.value) {
    const project = authProjectList.value.find(item => item.project_id === pid)
    // 暂时先返回true; 有项目ID的必须定义项目ID，要不等于没做权限处理
    if (!project) return true
    const prop = pre + key
    return Object.prototype.hasOwnProperty.call(project.tags, prop)
  }
  // 权限校验
  function checkAuth(key: string, pid: string = projectId.value, pre: string = prefix.value) {
    return isAuth(key, pre) ? hasAuth(key, pid, pre) : true
  }

  return { types, status, authProjectList, tags, project, projectId, prefix, isAuth, hasAuth, checkAuth }
}
